@@ -1,5 +1,5 @@
 package Selenium::Remote::Commands;
-$Selenium::Remote::Commands::VERSION = '0.2102';
+$Selenium::Remote::Commands::VERSION = '0.22';
 # ABSTRACT: Implement commands for Selenium::Remote::Driver
 
 use Moo;
@@ -69,6 +69,11 @@ has '_cmds' => (
                 'url'                => 'session/:sessionId/window/:windowHandle/position',
                 'no_content_success' => 0
             },
+            'maximizeWindow' => {
+                'method'             => 'POST',
+                'url'                => 'session/:sessionId/window/:windowHandle/maximize',
+                'no_content_success' => 1
+            },
             'setWindowSize' => {
                 'method'             => 'POST',
                 'url'                => 'session/:sessionId/window/:windowHandle/size',
@@ -279,11 +284,6 @@ has '_cmds' => (
                 'url'                => 'session/:sessionId/window',
                 'no_content_success' => 1
             },
-            'dragElement' => {
-                'method'             => 'POST',
-                'url'                => 'session/:sessionId/element/:id/drag',
-                'no_content_success' => 1
-            },
             'getElementSize' => {
                 'method'             => 'GET',
                 'url'                => 'session/:sessionId/element/:id/size',
@@ -349,15 +349,24 @@ has '_cmds' => (
                 'url'                => 'session/:sessionId/file',
                 'no_content_success' => 1
             },
+            'getLocalStorageItem' => {
+                'method'             => 'GET',
+                'url'                => '/session/:sessionId/local_storage/key/:key',
+                'no_content_success' => 0
+            },
+            'deleteLocalStorageItem' => {
+                'method'             => 'DELETE',
+                'url'                => '/session/:sessionId/local_storage/key/:key',
+                'no_content_success' => 1
+            }
+
+            # /session/:sessionId/local_storage
+            # /session/:sessionId/local_storage/key/:key
+            # /session/:sessionId/local_storage/size
+            # /session/:sessionId/session_storage
+            # /session/:sessionId/session_storage/key/:key
+            # /session/:sessionId/session_storage/size
 
-            #'setVisible' => {
-            #               'method' => 'POST',
-            #               'url' => 'session/:sessionId/visible'
-            #},
-            #'getVisible' => {
-            #               'method' => 'GET',
-            #               'url' => 'session/:sessionId/visible'
-            #},
         };
     }
 );
@@ -417,7 +426,7 @@ Selenium::Remote::Commands - Implement commands for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 0.2102
+version 0.22
 
 =head1 SEE ALSO
 
